@@ -19,6 +19,7 @@
 #define CHANNEL_MIXER_H
 
 #include "config.h"
+#include "libkwave_export.h"
 
 #include <QObject>
 #include <QPointer>
@@ -38,7 +39,7 @@ namespace Kwave
 
     class MixerMatrix;
 
-    class Q_DECL_EXPORT ChannelMixer: public Kwave::SampleSource
+    class LIBKWAVE_EXPORT ChannelMixer: public Kwave::SampleSource
     {
         Q_OBJECT
         public:
@@ -50,7 +51,7 @@ namespace Kwave
             ChannelMixer(unsigned int inputs, unsigned int outputs);
 
             /** Destructor */
-            virtual ~ChannelMixer() Q_DECL_OVERRIDE;
+            ~ChannelMixer() override;
 
             /**
              * Init function, you must call it once after creating and before
@@ -69,7 +70,7 @@ namespace Kwave
              *         the same as tracks()
              */
             virtual unsigned int tracksOfPort(const char *port) const
-                Q_DECL_OVERRIDE;
+                override;
 
             /**
              * Returns an indexed port, identified by name
@@ -77,10 +78,10 @@ namespace Kwave
              * @param track index of the track
              */
             virtual Kwave::StreamObject *port(
-                const char *port, unsigned int track) Q_DECL_OVERRIDE;
+                const char *port, unsigned int track) override;
 
             /** does nothing, work is done automatically in mix() */
-            virtual void goOn() Q_DECL_OVERRIDE
+            void goOn() override
             {
             }
 
