@@ -102,17 +102,17 @@ Kwave::OpusEncoder::OpusEncoder()
      m_bitrate(0),
      m_coding_rate(0),
      m_encoder_channels(0),
-     m_channel_mixer(Q_NULLPTR),
-     m_rate_converter(Q_NULLPTR),
+     m_channel_mixer(nullptr),
+     m_rate_converter(nullptr),
      m_frame_size(0),
      m_extra_out(0),
      m_opus_header(),
      m_max_frame_bytes(0),
-     m_packet_buffer(Q_NULLPTR),
-     m_encoder(Q_NULLPTR),
-     m_encoder_input(Q_NULLPTR),
-     m_last_queue_element(Q_NULLPTR),
-     m_buffer(Q_NULLPTR)
+     m_packet_buffer(nullptr),
+     m_encoder(nullptr),
+     m_encoder_input(nullptr),
+     m_last_queue_element(nullptr),
+     m_buffer(nullptr)
 {
 
     memset(&m_opus_header, 0x00, sizeof(m_opus_header));
@@ -421,7 +421,7 @@ bool Kwave::OpusEncoder::setupEncoder(QWidget *widget, unsigned int tracks,
     if (force_narrow) {
         for (unsigned int i = 0; i < m_opus_header.streams; i++ ) {
             if (force_narrow & (1 << i)) {
-                ::OpusEncoder *oe = Q_NULLPTR;
+                ::OpusEncoder *oe = nullptr;
 
                 opus_multistream_encoder_ctl(
                     m_encoder,
@@ -711,11 +711,11 @@ bool Kwave::OpusEncoder::writeOpusTags(QIODevice &dst)
     }
 
     // write the number of user tags
-    _writeInt(buffer, tags.count());
+    _writeInt(buffer, static_cast<quint32>(tags.count()));
 
     // serialize the tags into the buffer
     foreach (const QByteArray &tag, tags) {
-        _writeInt(buffer, tag.size());
+        _writeInt(buffer, static_cast<quint32>(tag.size()));
         buffer.write(tag);
     }
 
@@ -836,10 +836,7 @@ bool Kwave::OpusEncoder::encode(Kwave::MultiTrackReader &src,
                                 QIODevice &dst)
 {
     long int     eos             =  0;
-    opus_int64   nb_encoded      =  0;
     opus_int64   nb_samples      = -1;
-    opus_int64   total_bytes     =  0;
-    opus_int64   total_samples   =  0;
     ogg_int64_t  enc_granulepos  =  0;
     ogg_int64_t  last_granulepos =  0;
     ogg_int32_t  packet_id       =  1;
@@ -859,7 +856,6 @@ bool Kwave::OpusEncoder::encode(Kwave::MultiTrackReader &src,
 
         if (nb_samples < 0) {
             nb_samples = fillInBuffer(src);
-            total_samples += nb_samples;
             m_op.e_o_s = (nb_samples < m_frame_size) ? 1 : 0;
         }
         m_op.e_o_s |= eos; // eof from last pass
@@ -888,9 +884,7 @@ bool Kwave::OpusEncoder::encode(Kwave::MultiTrackReader &src,
             return false;
         }
 
-        nb_encoded     += m_frame_size;
         enc_granulepos += m_frame_size * 48000 / m_coding_rate;
-        total_bytes    += nbBytes;
         size_segments   = (nbBytes + 255) / 255;
 
         // flush early if adding this packet would make us end up with a
@@ -922,7 +916,6 @@ bool Kwave::OpusEncoder::encode(Kwave::MultiTrackReader &src,
         // low delay behavior.
         if ((!m_op.e_o_s ) && (max_ogg_delay > 5760)) {
             nb_samples = fillInBuffer(src);
-            total_samples += nb_samples;
             if (nb_samples < m_frame_size) eos = 1;
             if (nb_samples == 0) m_op.e_o_s = 1;
         } else {
@@ -980,27 +973,27 @@ bool Kwave::OpusEncoder::encode(Kwave::MultiTrackReader &src,
 /***************************************************************************/
 void Kwave::OpusEncoder::close()
 {
-    if (m_channel_mixer) delete m_channel_mixer;
-    m_channel_mixer = Q_NULLPTR;
+    delete m_channel_mixer;
+    m_channel_mixer = nullptr;
 
-    if (m_rate_converter) delete m_rate_converter;
-    m_rate_converter = Q_NULLPTR;
+    delete m_rate_converter;
+    m_rate_converter = nullptr;
 
-    if (m_buffer) delete m_buffer;
-    m_buffer = Q_NULLPTR;
+    delete m_buffer;
+    m_buffer = nullptr;
 
     if (m_encoder) opus_multistream_encoder_destroy(m_encoder);
-    m_encoder = Q_NULLPTR;
+    m_encoder = nullptr;
 
     ogg_stream_clear(&m_os);
 
     if (m_packet_buffer) free(m_packet_buffer);
-    m_packet_buffer = Q_NULLPTR;
+    m_packet_buffer = nullptr;
 
     if (m_encoder_input) free(m_encoder_input);
-    m_encoder_input = Q_NULLPTR;
+    m_encoder_input = nullptr;
 
-    m_last_queue_element = Q_NULLPTR;
+    m_last_queue_element = nullptr;
 }
 
 /***************************************************************************/
