@@ -1,3 +1,6 @@
+// SPDX-FileCopyrightText: 2017 Thomas Eschenbacher <Thomas.Eschenbacher@gmx.de>
+// SPDX-FileCopyrightText: 2024 Mark Penner <mrp@markpenner.space>
+// SPDX-License-Identifier: GPL-2.0-or-later
 /*************************************************************************
  *     K3BExportPlugin.cpp -  export of K3b project files
  *                             -------------------
@@ -54,6 +57,8 @@
 #include "K3BExportDialog.h"
 #include "K3BExportPlugin.h"
 
+using namespace Qt::StringLiterals;
+
 KWAVE_PLUGIN(export_k3b, K3BExportPlugin)
 
 /** mime type of K3b project files */
@@ -78,7 +83,7 @@ Kwave::K3BExportPlugin::K3BExportPlugin(QObject *parent,
      m_url(),
      m_pattern(),
      m_selection_only(false),
-     m_export_location(EXPORT_TO_SUB_DIR),
+     m_export_location(),
      m_overwrite_policy(USE_NEW_FILE_NAMES),
      m_block_info()
 {
@@ -114,13 +119,8 @@ int Kwave::K3BExportPlugin::interpreteParameters(QStringList &params)
     m_selection_only = (v != 0);
 
     // export location
-    param = params[3];
-    int where = param.toInt(&ok);
-    Q_ASSERT(ok);
-    if (!ok) return -EINVAL;
-    if ((where != EXPORT_TO_SAME_DIR) &&
-        (where != EXPORT_TO_SUB_DIR)) return -EINVAL;
-    m_export_location = static_cast<export_location_t>(where);
+    m_export_location = Kwave::URLfromUserInput(Kwave::Parser::unescape(params[3]));
+    if (!m_export_location.isValid()) return -EINVAL;
 
     // overwrite policy
     param = params[4];
@@ -302,43 +302,23 @@ QStringList *Kwave::K3BExportPlugin::setup(QStringList &params)
         (selection_right + 1 >= signalLength()));
     bool enable_selection_only = selected_something && !selected_all;
 
-    // show a "File / Save As..." dialog for the *.k3b file
-    QPointer<Kwave::K3BExportDialog> dialog =
-        new(std::nothrow) Kwave::K3BExportDialog(
-            _("kfiledialog:///kwave_export_k3b"),
-            K3B_FILE_SUFFIX + _("|") + i18nc(
-                "file type filter when exporting to K3b",
-                "K3b project file (*.k3b)"
-            ),
-            parentWidget(),
-            Kwave::URLfromUserInput(signalName()),
-            _("*.k3b"),
-            m_pattern,
-            m_selection_only,
-            enable_selection_only,
-            m_export_location,
-            m_overwrite_policy
-        );
-    if (!dialog) return nullptr;
+    // show a dialog to get the export settings
+    Kwave::K3BExportDialog *dialog = new Kwave::K3BExportDialog(
+        parentWidget(),
+        m_pattern,
+        m_selection_only,
+        enable_selection_only,
+        m_overwrite_policy,
+        Kwave::URLfromUserInput(signalName())
+    );
 
     dialog->setWindowTitle(description());
-    if ((dialog->exec() != QDialog::Accepted) || !dialog) {
-        delete dialog;
+    if (dialog->exec() != QDialog::Accepted) {
         return nullptr;
     }
 
-    QStringList *list = new(std::nothrow) QStringList();
-    Q_ASSERT(list);
-    if (!list) {
-        delete dialog;
-        return nullptr;
-    }
-
-    // user has pressed "OK"
-    QUrl url = dialog->selectedUrl();
+    QUrl url = dialog->projectFile();
     if (url.isEmpty()) {
-        delete dialog;
-        delete list;
         return nullptr;
     }
 
@@ -349,23 +329,34 @@ QStringList *Kwave::K3BExportPlugin::setup(QStringList &params)
     if (path.suffix() != K3B_FILE_SUFFIX.mid(2))
         url.setPath(name + K3B_FILE_SUFFIX.mid(1));
 
-    name                 = Kwave::Parser::escape(url.toString());
-    QString pattern      = Kwave::Parser::escape(dialog->pattern());
-    int export_location  = static_cast<int>(dialog->exportLocation());
-    int overwrite_policy = static_cast<int>(dialog->overwritePolicy());
-    bool selection_only  = (enable_selection_only) ?
+    QUrl dir = dialog->exportLocation();
+    if (dir.isEmpty()) {
+        return nullptr;
+    }
+
+    QStringList *list = new QStringList();
+    Q_ASSERT(list);
+    if (!list) {
+        return nullptr;
+    }
+
+    name                    = Kwave::Parser::escape(url.toString());
+    QString pattern         = Kwave::Parser::escape(dialog->pattern());
+    QString export_location = Kwave::Parser::escape(dir.path());
+    int overwrite_policy    = static_cast<int>(dialog->overwritePolicy());
+    bool selection_only     = (enable_selection_only) ?
         dialog->selectionOnly() : m_selection_only;
 
     *list << name;                              // url
     *list << pattern;                           // pattern
     *list << QString::number(selection_only);   // selection only
-    *list << QString::number(export_location);  // export location
+    *list << export_location;                   // export location
     *list << QString::number(overwrite_policy); // overwrite policy
 
     emitCommand(_("plugin:execute(export_k3b,") +
         name + _(",") + pattern + _(",")  +
         QString::number(selection_only)   + _(",") +
-        QString::number(export_location)  + _(",") +
+        export_location  + _(",") +
         QString::number(overwrite_policy) + _(")")
     );
 
@@ -590,17 +581,8 @@ int Kwave::K3BExportPlugin::start(QStringList &params)
     QString   k3b_filename = m_url.path();
     QFileInfo fi(k3b_filename);
     QString   base = fi.completeBaseName();
-    QString   out_dir;
-    QString   out_pattern;
-    if (m_export_location == Kwave::K3BExportPlugin::EXPORT_TO_SUB_DIR) {
-        // export to a subdir with the name "<filename>.dir"
-        out_dir     = fi.absolutePath() + QDir::separator() + base + _(".dir");
-        out_pattern = _("track-") + OUTFILE_PATTERN;
-    } else {
-        // use the same directory as the *.k3b file
-        out_dir     = fi.absolutePath();
-        out_pattern = base + _("-track-") + OUTFILE_PATTERN;
-    }
+    QString   out_dir = m_export_location.path();
+    QString   out_pattern = base + _("-track-") + OUTFILE_PATTERN;
     qDebug("out_dir     = '%s'", DBG(out_dir));
     qDebug("out_pattern = '%s'", DBG(out_pattern));
 
@@ -612,7 +594,7 @@ int Kwave::K3BExportPlugin::start(QStringList &params)
 
     // check: only mono or stereo files are supported
     if ((tracks.count() != 1) && (tracks.count() != 2)) {
-        qWarning("sorry, K3b can not handle %llu tracks", tracks.count());
+        qWarning("sorry, K3b can not handle %lld tracks", tracks.count());
         Kwave::MessageBox::sorry(parentWidget(), i18n(
             "Only mono and stereo files can be used for an audio CD. "
             "You can either deselect some channels or export the file "
@@ -657,7 +639,7 @@ int Kwave::K3BExportPlugin::start(QStringList &params)
             QStringList matches = files.filter(rx);
             if (matches.count() > 0) first = i + 1;
         }
-        qDebug("found first usable index -> %d", first);
+        qDebug("found first usable index -> %u", first);
     } else {
         // overwrite mode, always start at 1
     }
